Helper function when multiple variables are supplied for BART priors
Source:R/prior_bart.R
BARTPriors.RdThis is a helper function to specify several BARTPrior objects with the same hyper-parameters, but different variables.
Usage
BARTPriors(variable, hyper = 0.75, ...)
# S4 method for class 'character'
BARTPriors(variable, hyper = 0.75, ...)