Skip to contents

This is a helper function to specify several INLAPrior objects with the same hyper-parameters, but different variables.

Usage

INLAPriors(variables, type, hyper = c(0, 0.001), ...)

# S4 method for class 'vector,character'
INLAPriors(variables, type, hyper = c(0, 0.001), ...)

Arguments

variables

A vector of character matched against existing predictors or latent effects.

type

A character specifying the type of prior to be set.

hyper

A vector with numeric values to be used as hyper-parameters.

...

Variables passed on to prior object.

Value

A named list of Prior objects.

Examples

if (FALSE) { # \dontrun{
priors <- INLAPriors(c("forest", "temperature"), type = "normal")
length(priors)
} # }