Helper function when multiple variables and types are supplied for Stan priors
Source:R/prior_stan.R
STANPriors.RdThis is a helper function to specify several STANPrior with the same hyper-parameters, but different variables.

R/prior_stan.R
STANPriors.RdThis is a helper function to specify several STANPrior with the same hyper-parameters, but different variables.