Skip to contents

Function to include prior information as interaction constraints in an extreme gradient descent boosting model engine_xgboost. Interaction priors define groups of variables that are allowed to interact in the same tree path. Variables outside the same group are not allowed to interact.

Usage

XGBInteractionPrior(variables, ...)

# S4 method for class 'character'
XGBInteractionPrior(variables, ...)

Arguments

variables

A character vector matched against existing predictors or latent effects after XGBoost preprocessing.

...

Variables passed on to prior object.

Value

A Prior object.

Details

XGBoost interaction constraints are only supported by tree boosters. They can be combined with monotonic constraints supplied through XGBPrior.

Examples

 pp <- XGBInteractionPrior(c("forest", "temperature"))