Often it can make sense to fit an additional model to get a
grasp on the range of values that "beta" parameters can take. This function
takes an existing BiodiversityDistribution object and creates
PriorList object from them. The resulting object can be used to add
for instance priors to a new model.
Usage
get_priors(mod, target_engine, ...)
# S4 method for class 'ANY,character'
get_priors(mod, target_engine, ...)Arguments
- mod
A fitted
DistributionModelobject. If instead aBiodiversityDistributionobject is passed to this function, it simply returns the contained priors used for estimation (if any).- target_engine
A
characterfor which the priors should be created.- ...
Other parameters passed down.
Value
A PriorList object, or NULL when no compatible priors can be created.
Note
Not all engines support priors in similar ways. See the vignettes and help pages on that topic!
Examples
if (FALSE) { # \dontrun{
mod <- distribution(background) |>
add_predictors(covariates) |>
add_biodiversity_poipo(points) |>
engine_inlabru() |>
train()
get_priors(mod, target_engine = "BART")
} # }