Skip to contents

This helper function shows the code from a trained DistributionModel using the engine_stan. This function is emulated after a similar functionality in the brms R-package. It only works with models inferred with stan!

Usage

stancode(obj, ...)

stancode.DistributionModel(obj, ...)

Arguments

obj

Any prepared object.

...

not used.

Value

None.

See also

rstan, cmdstanr, brms

Examples

if (FALSE) { # \dontrun{
stancode(fitted_stan_model)
} # }