BiodiversityDataset prototype description
Source:R/class-biodiversitydataset.R
BiodiversityDataset-class.RdBiodiversityDataset prototype description
Public fields
nameThe default name of this dataset as
character.idA
characterwith the unique id for this dataset.equationA
formulaobject containing the equation of how this dataset is modelled.familyThe family used for this dataset as
character.linkThe link function used for this data as
character.typeweightA
numericcontaining custom weights per observation for this dataset.field_occurrenceA
characterwith the name of the column name containing observations.dataContains the observational data in
sfformat.use_interceptA
logicalflag on whether intercepts are included for this dataset.pseudoabsence_settingsOptionally provided pseudoabsence settings.
Methods
BiodiversityDataset$new()
Initializes the object and creates an empty list
Usage
BiodiversityDataset$new(
name,
id,
equation,
family,
link,
type,
weight,
field_occurrence,
data,
use_intercept,
pseudoabsence_settings
)Arguments
nameThe default name of this dataset as
character.idA
characterwith the unique id for this dataset.equationA
formulaobject containing the equation of how this dataset is modelled.familyThe family used for this dataset as
character.linkThe link function used for this data as
character.typeweightA
numericcontaining custom weights per observation for this dataset.field_occurrenceA
characterwith the name of the column name containing observations.dataContains the observational data in
sfformat.use_interceptA
logicalflag on whether intercepts are included for this dataset.pseudoabsence_settingsOptionally provided pseudoabsence settings.
BiodiversityDataset$print()
Print the names and properties of all Biodiversity datasets contained within
BiodiversityDataset$set_equation()
Set new equation and writes it into formula
Arguments
xA new
formulaobject.
BiodiversityDataset$get_type()
Get type of the dataset.
Arguments
shortA
logicalflag if this should be formatted in shortform.
Returns
A character with the type
BiodiversityDataset$get_column_occ()
Get field with occurrence information
Returns
A character with the occurence field
BiodiversityDataset$get_link()
Get custom link function
Returns
A character with the family for the dataset
BiodiversityDataset$get_observations()
Collect info statistics about number of observations
Returns
A numeric with the number of observations.
BiodiversityDataset$mask()
Convenience function to mask all input datasets.