BiodiversityDatasetCollection super class description
Source:R/class-biodiversitydataset.R
BiodiversityDatasetCollection-class.RdActs a container for a specified set of BiodiversityDataset contained within. Functions are provided to summarize across the BiodiversityDataset-class objects.
Public fields
dataA
listofBiodiversityDatasetobjects.nameThe default name of this collection as
character.
Methods
BiodiversityDatasetCollection$print()
Print the names and properties of all Biodiversity datasets contained within
Arguments
formatA
logicalflag on whether a message should be printed.
BiodiversityDatasetCollection$get_types()
Types of all biodiversity datasets included in this
Arguments
shortA
logicalflag whether types should be in short format.
Returns
A character vector.
BiodiversityDatasetCollection$get_names()
Get names and format them if necessary
Arguments
formatA
logicalflag whether names are to be formatted
Returns
A character vector.
BiodiversityDatasetCollection$set_data()
Add a new Biodiversity dataset to this collection.
Arguments
xA
characterwith the name or id of this dataset.valueA BiodiversityDataset
BiodiversityDatasetCollection$get_data_object()
Get a specific Biodiversity dataset by id
Arguments
idA
characterwith a given id for the dataset.
BiodiversityDatasetCollection$get_data()
Get all biodiversity observations from a given dataset.
Arguments
idA
characterwith a given id for the dataset.
BiodiversityDatasetCollection$get_coordinates()
Get coordinates for a given biodiversity dataset. Else return a wkt object
Arguments
idA
characterwith a given id for the dataset.
BiodiversityDatasetCollection$mask()
Convenience function to mask all input datasets.
BiodiversityDatasetCollection$rm_data()
Remove a specific biodiversity dataset by id
Arguments
idA
characterwith a given id for the dataset.
BiodiversityDatasetCollection$length()
Number of Biodiversity Datasets in connection
Returns
A numeric with the number of datasets.
BiodiversityDatasetCollection$get_observations()
Get number of observations of all datasets
Returns
A numeric with the number of observations across datasets.
BiodiversityDatasetCollection$get_equations()
Get equations from all datasets
Returns
A list vector with all equations across datasets.
BiodiversityDatasetCollection$get_families()
Get families from datasets.
Returns
A list vector with all families across datasets.
BiodiversityDatasetCollection$get_links()
Get custom link functions
Returns
A list vector with all link functions across datasets.
BiodiversityDatasetCollection$get_columns_occ()
Get fields with observation columns
Returns
A list vector with the names of observation columns.
BiodiversityDatasetCollection$get_weights()
Get the weights across datasets.
Returns
A list vector with the weights if set per dataset.
BiodiversityDatasetCollection$get_ids()
Get ids of all assets in the collection.
Returns
A list vector with the ids of all datasets.
BiodiversityDatasetCollection$get_id_byType()
Search for a specific biodiversity dataset with type
Arguments
typeA
characterfor a given data type.
Returns
A character with the id(s) of datasets with the given type.
BiodiversityDatasetCollection$get_id_byName()
Get id by name
Arguments
nameA
characterfor a given name.
Returns
A character with the id(s) of datasets with the given name.
BiodiversityDatasetCollection$show_equations()
Show equations of all datasets
Arguments
msgA
logicalon whether to use print a message instead.
Returns
Shows equations on screen or as character.