All trained Models inherit the options here plus any additional ones defined by the engine and inference.
Public fields
idA character id for any trained model
nameA description of the model as
character.modelA
listcontaining all input datasets and parameters to the model.settingsA
Settingsobject with information on inference.fitsA
listcontaining the prediction and fitted model..internalsA
listcontaining previous fitted models.
Methods
DistributionModel$new()
Initializes the object and creates an empty list
Usage
DistributionModel$new(name)Arguments
nameA description of the model as
character.
DistributionModel$get_name()
Return the name of the model
Returns
A character with the model name used.
DistributionModel$plot()
Plots the prediction if found.
Arguments
whatcharacterwith the specific layer to be plotted.
DistributionModel$show_duration()
Show model run time if settings exist
Returns
A numeric estimate of the duration it took to fit the models.
DistributionModel$summary()
Get effects or importance tables from model
Arguments
objA
characterof which object to return.
Returns
A data.frame summarizing the model, usually its coefficient.
DistributionModel$get_data()
Get specific fit from this Model
Arguments
xA
characterstating what should be returned.
Returns
A SpatRaster object with the prediction.
DistributionModel$set_data()
Set new fit for this Model.
Arguments
xThe name of the new fit.
valueThe
SpatRasterlayer (or model) to be inserted.
DistributionModel$get_thresholdvalue()
Get the threshold value if calculated
Returns
A numeric threshold value.
DistributionModel$get_resolution()
Get the resolution of the projection
Returns
numeric estimates of the distribution.
DistributionModel$calc_suitabilityindex()
Calculate a suitability index for a given projection
Details
Methods can either be normalized by the minimum and maximum. Or the relative total using the sumof values.
Returns
Returns a SpatRaster.
DistributionModel$get_centroid()
Get centroids of prediction layers
Returns
Returns a sf object.
DistributionModel$has_limits()
Logical indication if the prediction was limited.
Returns
A logical flag.
DistributionModel$has_latent()
Logical indication if the prediction has added latent factors.
Returns
A logical flag.
DistributionModel$mask()
Convenience function to mask all input datasets.