All trained Models inherit the options here plus any additional ones defined by the engine and inference.
Public fields
idA character id for any trained model
nameA description of the model as
character.modelA
listcontaining all input datasets and parameters to the model.settingsA
Settingsobject with information on inference.fitsA
listcontaining the prediction and fitted model..internalsA
listcontaining previous fitted models.
Methods
Method new()
Initializes the object and creates an empty list
Usage
DistributionModel$new(name)Arguments
nameA description of the model as
character.
Method print()
Print the names and summarizes the model within
Method plot()
Plots the prediction if found.
Arguments
whatcharacterwith the specific layer to be plotted.
Method show_duration()
Show model run time if settings exist
Returns
A numeric estimate of the duration it took to fit the models.
Method summary()
Get effects or importance tables from model
Arguments
objA
characterof which object to return.
Returns
A data.frame summarizing the model, usually its coefficient.
Method get_data()
Get specific fit from this Model
Arguments
xA
characterstating what should be returned.
Returns
A terra::SpatRaster object with the prediction.
Method set_data()
Set new fit for this Model.
Arguments
xThe name of the new fit.
valueThe
terra::SpatRasterlayer (or model) to be inserted.
Method get_thresholdvalue()
Get the threshold value if calculated
Returns
A numeric threshold value.
Method get_resolution()
Get the resolution of the projection
Returns
numeric estimates of the distribution.
Method calc_suitabilityindex()
Calculate a suitability index for a given projection
Details
Methods can either be normalized by the minimum and maximum. Or the relative total using the sumof values.
Returns
Returns a terra::SpatRaster.
Method has_latent()
Logical indication if the prediction has added latent factors.
Returns
A logical flag.
Method mask()
Convenience function to mask all input datasets.