Monotonic constrains for gradient descent boosting models do not work in the same way as other priors where a specific coefficient or magnitude of importance is specified. Rather monotonic constraints enforce a specific directionality of regression coefficients so that for instance a coefficient has to be positive or negative.
Important: Specifying a monotonic constrain for the engine_gdb does not guarantee that the variable is retained in the model as it can still be regularized out.
Usage
GDBPrior(variable, hyper = "increasing", ...)
# S4 method for class 'character'
GDBPrior(variable, hyper = "increasing", ...)Note
Similar priors can also be defined for the engine_xgboost via
XGBPrior().
References
Hofner, B., Müller, J., & Hothorn, T. (2011). Monotonicity‐constrained species distribution models. Ecology, 92(10), 1895-1901.