This is a helper function to specify several INLAPrior objects
with the same hyper-parameters, but different variables.
Usage
INLAPriors(variables, type, hyper = c(0, 0.001), ...)
# S4 method for class 'vector,character'
INLAPriors(variables, type, hyper = c(0, 0.001), ...)
Arguments
- variables
A vector of character matched against existing
predictors or latent effects.
- type
A character specifying the type of prior to be set.
- hyper
A vector with numeric values to be used as hyper-parameters.
- ...
Variables passed on to prior object.
See also
Other prior:
BARTPrior(),
BARTPriors(),
BREGPrior(),
BREGPriors(),
GDBPrior(),
GDBPriors(),
GLMNETPrior(),
GLMNETPriors(),
INLAPrior(),
STANPrior(),
STANPriors(),
XGBInteractionPrior(),
XGBInteractionPriors(),
XGBPrior(),
XGBPriors(),
add_priors(),
get_priors(),
priors(),
rm_priors()