Helper function when multiple variables and types are supplied for INLA priors
Source:R/prior_inla.R
INLAPriors.RdThis is a helper function to specify several INLAPrior objects with the same hyper-parameters, but different variables.

R/prior_inla.R
INLAPriors.RdThis is a helper function to specify several INLAPrior objects with the same hyper-parameters, but different variables.