This class describes the PredictorDataset and is used to store covariates within.
Public fields
idThe id for this collection as
character.dataA predictor dataset usually as
SpatRaster.nameA name for this object.
transformedSaves whether the predictors have been transformed somehow.
timeperiodA timeperiod field
is.spatialA
logicalflag on whether the predictor is spatial or not.
Methods
PredictorDataset$new()
Initializes the object and creates an empty list
Usage
PredictorDataset$new(id, data, transformed = FALSE, ...)Arguments
idThe id for this collection as
character.dataA predictor dataset usually as
SpatRaster.transformedA
logicalflag if predictors have been transformed. Assume not....Any other parameters found.
PredictorDataset$print()
Print the names and properties of all Biodiversity datasets contained within
Arguments
formatA
logicalflag on whether a message should be printed.
PredictorDataset$get_predictor_names()
Alias for get_names
Returns
character names of the data value.
PredictorDataset$get_data()
Get a specific dataset
Arguments
dflogicalon whether data is to be returned asdata.frame.na.rmlogicalifNAis to be removed from data.frame....Any other parameters passed on.
Returns
A SpatRaster or data.frame.
PredictorDataset$get_time()
Get time dimension of object.
Returns
A vector with the time dimension of the dataset.
PredictorDataset$get_projection()
Get Projection
Returns
A vector with the geographical projection of the object.
PredictorDataset$crop_data()
Utility function to clip the predictor dataset by another dataset
Details
This code now also is able to determine the temporally closest
layer. In case a data.frame exists as predictor, only that is returned.
PredictorDataset$mask()
Utility function to mask the predictor dataset by another dataset
PredictorDataset$set_data()
Add a new Predictor dataset to this collection
Arguments
valueA new
SpatRasterorstarsobject.
PredictorDataset$rm_data()
Remove a specific Predictor by name
Arguments
xcharacterof the predictor name to be removed.
PredictorDataset$summary()
Collect info statistics with optional decimals
Arguments
digitsnumericGiving the rounding precision
Returns
A data.frame summarizing the data.
PredictorDataset$has_derivates()
Indication if there are any predictors that are derivates of outers
Returns
A logical flag.