This class describes the PredictorDataset and is used to store covariates within.
Public fields
idThe id for this collection as
character.dataA predictor dataset usually as
terra::SpatRaster.nameA name for this object.
transformedSaves whether the predictors have been transformed somehow.
timeperiodA timeperiod field
is.spatialA
logicalflag on whether the predictor is spatial or not.
Methods
Method new()
Initializes the object and creates an empty list
Usage
PredictorDataset$new(id, data, transformed = FALSE, ...)Arguments
idThe id for this collection as
character.dataA predictor dataset usually as
terra::SpatRaster.transformedA
logicalflag if predictors have been transformed. Assume not....Any other parameters found.
Method print()
Print the names and properties of all Biodiversity datasets contained within
Arguments
formatA
logicalflag on whether a message should be printed.
Method get_data()
Get a specific dataset
Arguments
dflogicalon whether data is to be returned asdata.frame.na.rmlogicalifNAis to be removed from data.frame....Any other parameters passed on.
Returns
A terra::SpatRaster or data.frame.
Method get_time()
Get time dimension of object.
Returns
A vector with the time dimension of the dataset.
Method get_projection()
Get Projection
Returns
A vector with the geographical projection of the object.
Method crop_data()
Utility function to clip the predictor dataset by another dataset
Details
This code now also is able to determine the temporally closest
layer. In case a data.frame exists as predictor, only that is returned.
Method mask()
Utility function to mask the predictor dataset by another dataset
Method set_data()
Add a new Predictor dataset to this collection
Arguments
valueA new
terra::SpatRasterorstarsobject.
Method rm_data()
Remove a specific Predictor by name
Arguments
xcharacterof the predictor name to be removed.
Method summary()
Collect info statistics with optional decimals
Arguments
digitsnumericGiving the rounding precision
Returns
A data.frame summarizing the data.
Method has_derivates()
Indication if there are any predictors that are derivates of outers
Returns
A logical flag.
Method plot()
Basic Plotting function