Function to include prior information as interaction constraints
in an extreme gradient descent boosting model engine_xgboost. Interaction
priors define groups of variables that are allowed to interact in the same
tree path. Variables outside the same group are not allowed to interact.
Usage
XGBInteractionPrior(variables, ...)
# S4 method for class 'character'
XGBInteractionPrior(variables, ...)Arguments
- variables
A
charactervector matched against existing predictors or latent effects after XGBoost preprocessing.- ...
Variables passed on to prior object.
Details
XGBoost interaction constraints are only supported by tree boosters.
They can be combined with monotonic constraints supplied through XGBPrior.
See also
Prior, XGBPrior and engine_xgboost.
Other prior:
BARTPrior(),
BARTPriors(),
BREGPrior(),
BREGPriors(),
GDBPrior(),
GDBPriors(),
GLMNETPrior(),
GLMNETPriors(),
INLAPrior(),
INLAPriors(),
STANPrior(),
STANPriors(),
XGBInteractionPriors(),
XGBPrior(),
XGBPriors(),
add_priors(),
get_priors(),
priors(),
rm_priors()
Examples
if (FALSE) { # \dontrun{
pp <- XGBInteractionPrior(c("forest", "temperature"))
} # }